#
# spec file for package epy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           epy
Version:        2025.5.27+git.1749648520.0d836a6
Release:        1.1
Summary:        CLI ebook reader
License:        GPL-3.0-only
URL:            https://git.sr.ht/~mcepl/epy
# Source:         https://files.pythonhosted.org/packages/source/e/epy-reader/epy-reader-%%{version}.tar.gz#/epy-%%{version}.tar.gz
Source:         epy-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  python3-curses
BuildRequires:  python3-pip
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       python3-curses
Requires:       python3-standard-imghdr
Suggests:       dictd
Suggests:       mimic
Suggests:       sdcv
BuildArch:      noarch

%description
CLI Ebook reader. Fork of epr with these extra features:

    Supported formats:
        Epub (.epub, .epub3)
        FictionBook (.fb2)
        Mobi (.mobi)
        AZW3 (.azw3), some but not all

    Reading progress percentage
    Bookmarks
    External dictionary integration (sdcv or dict)
    Inline formats: bold and italic (depend on terminal and font
        capability. Italic only supported in python>=3.7)
    Text-to-Speech (with additional setup)
    Double Spread

%prep
%autosetup -p1 -n epy-%{version}

# All those shebangs are just harmful
find . -name \*.py -print0 | while IFS= read -r -d $'\0' script; do
    sed -i "1{/#!\s*\/usr\/bin\/\(env \)\?python/d}" "$script"
    chmod -x "$script"
done

%build
%python3_pyproject_wheel

%install
%python3_pyproject_install
%fdupes %{buildroot}/%{python3_sitelib}
%python3_fix_shebang

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}/%{python3_sitelib}
pytest -v tests

%files
%doc README.md
%license LICENSE
%{_bindir}/epy
%{python3_sitelib}/epy_reader-2025.5.27.dist-info
%{python3_sitelib}/epy_reader

%changelog
* Wed Jun 11 2025 mcepl@cepl.eu
- Update to version 2025.5.27+git.1749648520.0d836a6:
  * chore: switch from poetry to ordinary setup (using setuptools)
  * feat: make it configurable to use colors or be terminal neutral
  * fix: remove all typing errors
  * chore: move getter for default config directory out of class
  * fix: handle the internal structure better, take care of multiprocessing
  * ci: centralize DEBUG variable for debugging
  * chore: switch DEBUG to True
  * ci: simple .builds.yml for Sourcehut CI
  * Use os.path.expanduser.
  * Use contextlib.connect context manager instead of playing with try manually.
* Mon Mar 17 2025 Matej Cepl <mcepl@cepl.eu>
- Don't make the build specific to some particular version of
  Python.
* Mon Jun  3 2024 mcepl@cepl.eu
- Update to version 2022.12.11+git.1686460830.6b0e9fe:
  * Deprecate setup.py
  * Try fixing #87 & bump version
  * add speaker support for gtts-cli | mpv (#88)
  * Update AUR package name (#92)
* Mon Jun  3 2024 Matej Cepl <mcepl@cepl.eu>
- Actually, make buildable on Leap (remove unnecessary dependency
  on a package which is not in Leap).
- Add python3_fix_shebang_path treatment (bsc#1212476)
* Wed Jan 10 2024 Michal Suchanek <msuchanek@suse.com>
- Make buildable on Leap.
* Wed Dec 20 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Do not write non-deterministic .pyc files in tests
* Sat Mar  4 2023 mcepl@cepl.eu
- Update to version 2022.12.11+git.1675870044.c7a87f3:
  * Fix versioning consistency
  * Bugfix #61 (#84)
  * Simplify logic
  * Bump version to v2022.12.11
  * Fix issue #73
  * Ignore .envrc
  * A suggestion for enhancing the Readme file (#69)
  * Update tests trigger path
  * Update tests and Makefile
  * Update tests
* Wed Oct  5 2022 mcepl@cepl.eu
- Update to version 2022.4.18+git.1664754357.6dd1860:
  * Update tests trigger path
  * Update tests and Makefile
  * Update tests
  * Restore and update setup.py for AUR pkg compatibility
  * Major refactor: breakdown epy.py script into package project structure for easier development Squashed commit of the following:
  * Setup debugger: debugpy
  * Revert "Add user setting for indenting paragraphs (#63)" Issue with inline style (italic, bold)
  * Add user setting for indenting paragraphs (#63)
* Mon Apr 25 2022 mcepl@cepl.eu
- Update to version 2022.4.18+git.1650237821.50dd4fa:
  * Bugfix #57: Unresolved relative path for epub contents
  * Update dev env configurations
  * Add wkdict to supported dict backends
  * docs: define word setup (#55)
  * Add signal handler
  * Breakdown parse_cli_args into its own method
  * Remove body: from workflow
  * Move sponsor to FUNDING
  * Update changelog in README
  * Add debugger on parallel letter counting process
  * Fix process.join() issue for unstarted process
  * Bugfix #51: Stop/prevent scrolling at the end of ebook
  * Add 'force_wait' for letters counting process
  * Add library menu
  * Verbose loader
  * Fixed url parser with pathlib.PurePosixPath
  * CLI help interface
  * More explicit 'content_path'
  * Hotfix: image location reference issue
  * Hotfix: url meta window issue and update version
  * URL early support
  * Improve cli help interface
  * New implementation of cli args parser
  * Restructured tests
  * Add vim config
- Run tests
* Sat Jan  8 2022 mcepl@cepl.eu
- Update to version 2022.1.8+git.1641653565.c1f9b4e:
  * Update README.md: added AUR installation
  * Delete .mkpkg script
* Sat Jan  8 2022 mcepl@cepl.eu
- Update to version 2021.10.23+git.1641627031.7bd659d:
  * .mkpkg -> Makefile
  * Patch PKGBUILD
* Sat Jan  8 2022 mcepl@cepl.eu
- Update to version 2021.10.23+git.1641622438.69c2f80:
  * Hotfix: curses has no attrib window in termux
  * Added default color config
  * Added PKGBUILD for Arch
  * Adjust setup.py and pyproject.toml to include epy_extras
  * Cleanup on failed ebook initialization
  * Initial prepackaging kindleunpack with epy
  * Use setuptools as setup backend instead of poetry
  * Update version and README.md
  * Change history matching key from filepath to title author
  * Initial library implementation
  * Always calculate reading_progress whenever possible, just not always shown
  * Refactor attribute name
  * Fixed book metadata
  * Add (sup|sub)script lookup table
  * Implement HTMLtoLines._group_spans_by_row()
  * Hotfix: adjust starting_line for inline style
  * Add text mark/span grouper method
  * Initial refactor: inline styling
  * Add ipdb dev dependency
  * Hotfix: Skip adding toc entry for empty label name
  * Update development env using poetry
  * Fix path resolver for Mobi.get_img_bytstr()
  * Add tests
  * Add requirements-dev.txt
  * Add support for Epub==v1.0 and simplify path resolver
  * Remove bad try-except block
  * Refactor Epub and Mobi object
  * Hotfix: Update docstr
  * Fixed plethora type issues
  * Added SpeakerBaseModel as TTS engine wrapper
  * Use mimic instead of pico2wave. (#44)
  * Update README.md: remove AUR installation instruction
  * Update .gitignore
  * Fixed unavailable curses.A_ITALIC and update version
  * Update LICENSE
  * Allow setting language for TTS. (#43)
- Remove upstreamed mimic.patch.
* Mon Dec 20 2021 Matej Cepl <mcepl@suse.com>
- Replace tts_lang.patch with mimic.patch, switching the TTS engine to
  free mimic (svox is non-free), and allowing inclusion into openSUSE.
* Fri Dec 17 2021 Matej Cepl <mcepl@suse.com>
- Add tts_lang.patch to allow setting language of TTS
  (gh#wustho/epy#43).
* Sat Nov 27 2021 mcepl@cepl.eu
- Update to version 2021.10.23+git.1636702550.2ab1584:
  * Fixed reset to beginning of row when resizing term and Seamless==True
  * Implement SeamlessBetweenChapters Squashed commit of the following:
  * Minor annotation & prevent next page animation on edge of book
  * Removed Board class
  * Added TextStructure dataclass
  * Give styling to images
  * Better image opening scheme
  * Refactor parser.get_lines(width) to get_lines(textwidth)
  * Fixed image cursor on double spread and progress pctg in double spread
  * Refactor variables
* Wed Jul 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Simplify spec, remove differing python versions from initial package generation
- Change package name to epy as it better reflects the acutal package name on GitHub
* Wed Jul 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Add Suggests for supported dictionary applications
* Wed Jul 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Initial package version
